import { actionTypes as asyncDataFetchActions } from '@bufferapp/async-data-fetch';
import reducer from './reducer';

describe('reducer', () => {
  it('has no metrics in initial state', () => {
    const metrics = reducer(undefined, {
      type: 'TEST_ACTION',
    }).metrics;
    expect(metrics).toEqual([]);
  });
  it('initial state is loading', () => {
    const loading = reducer(undefined, {
      type: 'TEST_ACTION',
    }).loading;
    expect(loading).toBeTruthy();
  });
  it('has no metrics upon receiving FETCH_START', () => {
    const metrics = reducer(undefined, {
      type: `posts_summary_${asyncDataFetchActions.FETCH_START}`,
    }).metrics;
    expect(metrics).toEqual([]);
  });
  it('on fetch_success stops loading', () => {
    const state = reducer(undefined, {
      type: `posts_summary_${asyncDataFetchActions.FETCH_SUCCESS}`,
    });
    expect(state.loading).toBeFalsy();
  });
  it('updates the state with the metrics received on fetch_success', () => {
    const metrics = ['one', 'two', 'three'];
    const state = reducer(undefined, {
      type: `posts_summary_${asyncDataFetchActions.FETCH_SUCCESS}`,
      result: metrics,
    });
    expect(state.metrics).toEqual(metrics);
  });
  it('on fetch_error stops loading and set error state', () => {
    const state = reducer(undefined, {
      type: `posts_summary_${asyncDataFetchActions.FETCH_FAIL}`,
    });
    expect(state.loading).toBeFalsy();
    expect(state.hasError).toBeTruthy();
  });
});
